summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/fileio.c20
-rw-r--r--src/version.c2
2 files changed, 12 insertions, 10 deletions
diff --git a/src/version.c b/src/version.c
index 4bd054c7f..eda5ad42d 100644
--- a/src/version.c
+++ b/src/version.c
@@ -762,6 +762,8 @@ static char *(features[]) =
static int included_patches[] =
{ /* Add new patch number below this line */
/**/
+ 96,
+/**/
95,
/**/
94,
diff --git a/src/fileio.c b/src/fileio.c
index 428e40824..0c56a1ef0 100644
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* will be automatically executed for <event>
* when editing a file matching <pat>, in
* the current group.
* :autocmd <event> <pat> Show the auto-commands associated with
* <event> and <pat>.
* :autocmd <event> Show the auto-commands associated with
* <event>.
* :autocmd Show all auto-commands.
* :autocmd! <event> <pat> <cmd> Remove all auto-commands associated with
* <event> and <pat>, and add the command
* <cmd>, for the current group.
* :autocmd! <event> <pat> Remove all auto-commands associated with
* <event> and <pat> for the current group.
* :autocmd! <event> Remove all auto-commands associated with
* <event> for the current group.
* :autocmd! Remove ALL auto-commands for the current
* group.
*
* Multiple events and patterns may be given separated by commas. Here are
@@ -8534,7 +8534,7 @@ do_autocmd(char_u *arg_in, int forceit)
if (!forceit && *cmd == NUL)
{
/* Highlight title */
- MSG_PUTS_TITLE(_("\n--- Auto-Commands ---"));
+ MSG_PUTS_TITLE(_("\n--- Autocommands ---"));
}
/*
@@ -9602,7 +9602,7 @@ apply_autocmds_group(
autocmd_match = fname;
- /* Don't redraw while doing auto commands. */
+ /* Don't redraw while doing autocommands. */
++RedrawingDisabled;
save_sourcing_name = sourcing_name;
sourcing_name = NULL; /* don't free this one */
@@ -9855,7 +9855,7 @@ auto_next_pat(
: ap->buflocal_nr == apc->arg_bufnr)
{
name = event_nr2name(apc->event);
- s = _("%s Auto commands for \"%s\"");
+ s = _("%s Autocommands for \"%s\"");
sourcing_name = alloc((unsigned)(STRLEN(s)
+ STRLEN(name) + ap->patlen + 1));
if (sourcing_name != NULL)
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* when editing a file matching <pat>, in
* the current group.
- * :autocmd <event> <pat> Show the auto-commands associated with
+ * :autocmd <event> <pat> Show the autocommands associated with
* <event> and <pat>.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* <event> and <pat>.
- * :autocmd <event> Show the auto-commands associated with
+ * :autocmd <event> Show the autocommands associated with
* <event>.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* <event>.
- * :autocmd Show all auto-commands.
- * :autocmd! <event> <pat> <cmd> Remove all auto-commands associated with
+ * :autocmd Show all autocommands.
+ * :autocmd! <event> <pat> <cmd> Remove all autocommands associated with
* <event> and <pat>, and add the command
* <cmd>, for the current group.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* <event> and <pat>, and add the command
* <cmd>, for the current group.
- * :autocmd! <event> <pat> Remove all auto-commands associated with
+ * :autocmd! <event> <pat> Remove all autocommands associated with
* <event> and <pat> for the current group.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* <event> and <pat> for the current group.
- * :autocmd! <event> Remove all auto-commands associated with
+ * :autocmd! <event> Remove all autocommands associated with
* <event> for the current group.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
* <event> for the current group.
- * :autocmd! Remove ALL auto-commands for the current
+ * :autocmd! Remove ALL autocommands for the current
* group.
*